@@ -1,8 +1,5 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from sql import Table
-from sql.functions import Overlay, Position
-
 from trytond.model import ModelSQL, fields
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
@@ -11,8 +8,7 @@ __all__ = ['Purchase', 'PurchaseIgnoredInvoiceLine',
     'HandleInvoiceException']
 
 
-class Purchase:
-    __metaclass__ = PoolMeta
+class Purchase(metaclass=PoolMeta):
     __name__ = 'purchase.purchase'
     invoice_lines = fields.Function(fields.One2Many('account.invoice.line',
             None, 'Invoice Lines'), 'get_invoice_lines',
@@ -21,21 +17,6 @@ class Purchase:
             'purchase.purchase-ignored-account.invoice.line',
             'purchase', 'invoice', 'Invoice Lines Ignored', readonly=True)
 
-    @classmethod
-    def __register__(cls, module_name):
-        cursor = Transaction().connection.cursor()
-        model_data = Table('ir_model_data')
-        # Migration from 1.2: packing renamed into shipment
-        cursor.execute(*model_data.update(
-                columns=[model_data.fs_id],
-                values=[Overlay(model_data.fs_id, 'shipment',
-                        Position('packing', model_data.fs_id),
-                        len('packing'))],
-                where=model_data.fs_id.like('%packing%')
-                & (model_data.module == module_name)))
-
-        super(Purchase, cls).__register__(module_name)
-
     def get_invoice_lines(self, name):
         return list({il.id for l in self.lines for il in l.invoice_lines})
 
@@ -86,8 +67,9 @@ class Purchase:
     def copy(cls, purchases, default=None):
         if default is None:
             default = {}
-        default = default.copy()
-        default['invoice_lines_ignored'] = None
+        else:
+            default = default.copy()
+        default.setdefault('invoice_lines_ignored', None)
         return super(Purchase, cls).copy(purchases, default=default)
 
 
@@ -101,8 +83,7 @@ class PurchaseIgnoredInvoiceLine(ModelSQL):
             ondelete='RESTRICT', select=True, required=True)
 
 
-class HandleInvoiceException:
-    __metaclass__ = PoolMeta
+class HandleInvoiceException(metaclass=PoolMeta):
     __name__ = 'purchase.handle.invoice.exception'
 
     def transition_handle(self):
@@ -120,5 +101,5 @@ class HandleInvoiceException:
             Purchase.write([purchase], {
                     'invoice_lines_ignored': [('add', invoice_lines)],
                     })
-        Purchase.process([purchase])
+        Purchase.__queue__.process([purchase])
         return state
